@@ -1,7 +1,9 @@
 //! Utils for diff text
+pub use ansi_term::Style;
+
 use crate::basic;
 use crate::format_table;
-use ansi_term::{Colour, Style};
+use ansi_term::{Colour};
 use prettytable::{Cell, Row};
 use std::fmt;
 
@@ -248,7 +250,7 @@ impl<'a> LineChangeset<'a> {
         self
     }
     /// Align new lines inside diff
-    pub fn set_aling_new_lines(mut self, val: bool) -> Self {
+    pub fn set_align_new_lines(mut self, val: bool) -> Self {
         self.aling_new_lines = val;
         self
     }
@@ -537,7 +539,7 @@ void func3(){}
     println!("====");
     diff_lines(code1_a, code1_b)
         .names("left", "right")
-        .set_aling_new_lines(true)
+        .set_align_new_lines(true)
         .prettytable();
 }
 
